#
# spec file for package xiterm
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define	appdefdir  %{_datadir}/X11
%define xincludes  %{_includedir}
%define xlibraries %{_prefix}/%{_lib}
Name:           xiterm
Version:        0.5.20040304
Release:        301.9
Summary:        Internationalized Terminal Emulator for X11
# cvs -d:pserver:anonymous@www.openi18n.org:/cvsroot login (no password to login)
# cvs -d:pserver:anonymous@www.openi18n.org:/cvsroot co iterm
# tar jcvf iterm-0.5.20040304.tar.bz2 iterm
License:        SUSE-CPL-0.5
Group:          System/X11/Terminals
Source0:        iterm-0.5.20040304.tar.bz2
Source1:        fonts.tar.bz2
Patch0:         xiterm-fontset.patch
Patch1:         fbiterm-enhance.dif
Patch2:         intptr.patch
Patch3:         null-pointer.patch
Patch4:         enable-scrollbar.patch
Patch5:         fbiterm-exit-code.dif
Patch6:         fbiterm-devconsole.dif
Patch7:         fbiterm-combine-optimize.patch
Patch8:         xiterm-implicit-fortify-decl.patch
Patch9:         xiterm-asneeded-and-dso.patch
Patch10:        xiterm-automake-1.13.patch
Patch11:        implict-ptsname-decl.patch
Patch12:        stropts.patch
# do not enable application keypad mode [bsc#1158271]
Patch13:        xiterm-no-keypad-application-mode.patch
BuildRequires:  bdftopcf
BuildRequires:  fribidi-devel
BuildRequires:  gtk2-devel
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xfont)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xt)
Provides:       locale(xorg-x11:ja;ko;zh)
%if 0%{?suse_version} > 1130
BuildRequires:  utempter-devel
%else
BuildRequires:  utempter
%endif
%if 0%{?suse_version} >= 1330
Requires(pre):  group(tty)
%endif

%description
Internationalized Terminal Emulator for X11

%package -n fbiterm
Summary:        Internationalized Terminal Emulator for Framebuffers
Group:          System/X11/Terminals
Provides:       locale(ja;ko;zh)
%if 0%{?suse_version} >= 1330
Requires(pre):  group(tty)
%endif

%description -n fbiterm
An internationalized terminal emulator for framebuffers.

%package -n gtkiterm
Summary:        Internationalized Terminal Emulator for GTK
Group:          System/X11/Terminals
Provides:       locale(gtk2:ja;ko;zh)
%if 0%{?suse_version} >= 1330
Requires(pre):  group(tty)
%endif

%description -n gtkiterm
An internationalized terminal emulator for GTK.

%package -n libiterm1
Summary:        Internationalized Terminal Emulator Library
# ncurses provides an alternative /usr/share/terminfo/i/iterm, the files conflict though
Group:          System/Libraries
Conflicts:      terminfo-iterm
# O/P added in 12.3
Provides:       libiterm = %version-%release
Obsoletes:      libiterm < %version-%release

%description -n libiterm1
This is a portable library for internationalized terminal emulator. All
you need to make terminal emulator is to implements Callback functions,
like a drawing string on specific column and row, or set
fore/background color and so on.

%package -n libiterm-devel
Summary:        Header files and development libraries for libiterm
Group:          Development/Libraries/Other
Requires:       libiterm1 = %{version}

%description -n libiterm-devel
Header files and development libraries for libiterm

%package -n libXiterm1
Summary:        Terminal emulator Xaw widget library based on libiterm
# O/P added in 12.3
Group:          System/Libraries
Provides:       libXiterm = %version-%release
Obsoletes:      libXiterm < %version-%release

%description -n libXiterm1
Terminal emulator Xaw widget library based on libiterm

%package -n libXiterm-devel
Summary:        Header files and development libraries for libXiterm
Group:          Development/Libraries/Other
Requires:       libXiterm1 = %{version}

%description -n libXiterm-devel
Header files and development libraries for libXiterm

%prep
%setup -q -n iterm -a 1
%patch0 -p 1 -b .fontset
%patch1 -p 0
%patch2 -p 0 -b .intptr
%patch3 -p 1 -b .null-pointer
%patch4 -p 1 -b .enable-scrollbar
%patch5 -p 0 -b .exit-code
%patch6 -p 0
%patch7
%patch8
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
find . -name CVS -type d -exec rm -rf {} +
find . -name .cvsignore -type f -delete
find . -type f -exec chmod u+w {} +
for i in INSTALL* README*
do
   mv $i $i.framework
done

%build
export CFLAGS="%{optflags}"
pushd lib
    autoreconf --force --install
%configure --disable-static --x-includes=%{xincludes} \
		--x-libraries=%{xlibraries} \
		--with-utempter \
		--enable-fribidi
%make_build
popd
pushd unix/Xaw/lib
    autoreconf --force --install
%configure --disable-static --x-includes=%{xincludes} \
		--x-libraries=%{xlibraries}
    %make_build INCLUDES="-I../../../lib/include -I../lib"
popd
pushd unix/Xaw/src
autoreconf --force --install
%configure --disable-static --x-includes=%{xincludes} \
		--x-libraries=%{xlibraries}
    %make_build INCLUDES="-I../../../lib/include -I../lib" LDFLAGS="-L../../../lib/src/.libs -L../lib/.libs"
popd
pushd unix/fbiterm
    autoreconf --force --install
    export LIBS="-lfreetype -lm"
%configure --disable-static \
		--x-includes=%{xincludes} \
		--x-libraries=%{xlibraries}
    %make_build INCLUDES="-I../../../lib/include" \
         'LDFLAGS=-L../../../lib/src/.libs'
popd
pushd unix/gtk
    %make_build CFLAGS="$CFLAGS -I../../../lib/include -L../../../lib/src/.libs"
popd

%install
%make_install -C lib
%make_install -C unix/Xaw/lib
%make_install -C unix/Xaw/src
%make_install -C unix/fbiterm
pushd unix/gtk
    install -m 755 src/gtkiterm %{buildroot}%{_prefix}/bin
popd
# install terminfo entry-description
mkdir -p %{buildroot}%{_datadir}/terminfo/i
tic -o %{buildroot}%{_datadir}/terminfo/ unix/terminfo/iterm.terminfo
mkdir -p %{buildroot}%{appdefdir}/{ja,ja_JP.UTF-8,}/app-defaults
install -m 644 unix/Xaw/src/XIterm %{buildroot}%{appdefdir}/app-defaults/XIterm
install -m 644 unix/Xaw/src/XIterm.ja %{buildroot}%{appdefdir}/ja/app-defaults/XIterm
iconv -f EUC-JP -t UTF-8 < unix/Xaw/src/XIterm.ja > unix/Xaw/src/XIterm.ja.UTF-8
install -m 644 unix/Xaw/src/XIterm.ja.UTF-8 %{buildroot}%{appdefdir}/ja_JP.UTF-8/app-defaults/XIterm
# install fallback fonts for fbiterm:
mkdir -p %{buildroot}%{_datadir}/fbiterm/fonts
pushd fonts
    for i in *.bdf
    do
	bdftopcf ${i} | gzip --no-name --best --stdout --force > %{buildroot}%{_datadir}/fbiterm/fonts/${i%.bdf}.pcf.gz
    done
popd
rm -f %{buildroot}%{_libdir}/*.la
chmod 0755 %{buildroot}/%{_bindir}/*

%post -n libiterm1 -p /sbin/ldconfig

%postun -n libiterm1 -p /sbin/ldconfig

%post -n libXiterm1 -p /sbin/ldconfig

%postun -n libXiterm1 -p /sbin/ldconfig

%files
%doc unix/Xaw/README* unix/Xaw/src/{COPYING,ChangeLog,INSTALL*}
%attr(-,root,tty) %{_bindir}/xiterm
%dir %{appdefdir}/app-defaults
%{appdefdir}/app-defaults/*
%dir %{appdefdir}/ja/
%dir %{appdefdir}/ja/app-defaults/
%dir %{appdefdir}/ja_JP.UTF-8/
%dir %{appdefdir}/ja_JP.UTF-8/app-defaults/
%{appdefdir}/*/app-defaults/*

%files -n fbiterm
%doc unix/fbiterm/{AUTHORS,COPYING,ChangeLog,INSTALL,NEWS,README*}
%attr(-,root,tty) %{_bindir}/fbiterm
%dir %{_datadir}/fbiterm/
%dir %{_datadir}/fbiterm/fonts
%{_datadir}/fbiterm/fonts/*

%files -n gtkiterm
%doc unix/gtk/README*
%attr(-,root,tty) %{_bindir}/gtkiterm

%files -n libiterm1
%{_libdir}/libiterm.so.1*
%{_datadir}/terminfo/i/iterm*

%files -n libiterm-devel
%doc README* INSTALL* RELNOTES* lib/{COPYING,README*,INSTALL*,ChangeLog} lib/docs/
%doc unix/terminfo/
%{_libdir}/libiterm.so
%{_includedir}/iterm/

%files -n libXiterm1
%{_libdir}/libXiterm.so.1*

%files -n libXiterm-devel
%doc unix/Xaw/lib/ChangeLog
%{_libdir}/libXiterm.so
%{_includedir}/Iterm*.h

%changelog
* Mon Aug 23 2021 Jan Engelhardt <jengelh@inai.de>
- Remove --with-pic which has no effect with --disable-static.
- Trim old specfile constructs.
* Wed Sep  2 2020 pgajdos@suse.com
- added patches
  fix do not enable application keypad mode [bsc#1158271]
  + xiterm-no-keypad-application-mode.patch
- big thanks to Stefan Hundhammer
* Thu Aug  8 2019 Andreas Schwab <schwab@suse.de>
- stropts.patch: remove use of obsolete XSI STREAMS interface
* Tue Sep 19 2017 dimstar@opensuse.org
- Conflict libiterm1 with terminfo-iterm: terminfo-iterm is an
  alternative to xiterm, and the conflict is meant to be.
* Wed Aug 16 2017 schwab@suse.de
- Prerequire group(tty)
* Sat Apr 29 2017 bwiedemann@suse.com
- call gzip -n to make build fully reproducible
* Tue Jul 12 2016 schwab@suse.de
- implict-ptsname-decl.patch: fix implicit declaration of ptsname with
  glibc >= 2.24
* Sat Nov  1 2014 crrodriguez@opensuse.org
- Switch to pkgconfig() buildrequires instead of using
  metapackage xorg-x11-devel
* Mon Jul 28 2014 pgajdos@suse.com
- README.SuSE renamed to README.SUSE [bnc#889032] (internal)
* Tue Mar  5 2013 pgajdos@suse.com
- builds with automake 1.13
  * automake-1.13.patch
* Thu Feb 14 2013 pgajdos@suse.com
- add bdftopcf into build requires [bnc#803276]
* Tue Nov 27 2012 cfarrell@suse.com
- license update: SUSE-CPL-0.5
* Fri Nov 23 2012 jengelh@inai.de
- Employ shared library naming guidelines
- Use %%_smp_mflags for parallel build
* Fri Jan 27 2012 pgajdos@suse.com
- build with asneeded
  * asneeded-and-dso.patch
* Wed Nov 23 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Wed Jul 13 2011 coolo@novell.com
- fix permissions to get rpm to extract requires
* Mon Nov  8 2010 coolo@novell.com
- remove support for pre-9.1
* Thu Sep  9 2010 aj@suse.de
- BuildRequire utempter-devel
* Mon Feb 22 2010 coolo@novell.com
- remove gnome paths in autoreconf - removing autoreconf did not
  work as the time stamps are broken
* Fri Jun 19 2009 coolo@novell.com
- disable as-needed for this package as it fails to build with it
* Wed Oct 15 2008 crrodriguez@suse.de
- fix implicit-fortify-decl issues
- remove static libraries and "la" files
* Mon Mar  3 2008 mfabian@suse.de
- make rpmlint happy:
  • add post-scripts with ldconfig calls for the library packages.
  • remove BuildRequires for suse_version <= 910.
* Thu Mar 29 2007 ro@suse.de
- added ncurses-devel to buildreq
* Fri Feb  2 2007 uli@suse.de
- fbiterm: add support for combining characters (fixes Thai, Lao),
  remove getenv() call from inner loop, minor optimizations
* Tue Aug 15 2006 mfabian@suse.de
- prefer fonts in /usr/share/fonts over fonts in
  /usr/lib/X11/fonts (move to X11R7).
* Mon Aug  7 2006 mfabian@suse.de
- fix build for SUSE LINUX 10.0 in the openSUSE build service
  (aclocal.m4 was not writeable).
* Fri Aug  4 2006 mfabian@suse.de
- adapt for Xorg X11R7 (paths changed).
* Tue Feb 28 2006 mfabian@suse.de
- add "Provides: locale(...)".
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Aug  2 2005 ro@suse.de
- use gtk2-devel-packages in nfb
* Mon May 10 2004 tiwai@suse.de
- allow to run fbiterm on /dev/console (bug #40134).
- reverted the last fix for libXfont and freetype linking.
* Mon Apr 19 2004 tiwai@suse.de
- link libXfont and freetype statically with fbiterm
  (bug #39141)
* Mon Apr  5 2004 mfabian@suse.de
- Bugzilla 38365: add 8x16.bdf (from XFree86) and b16.bdf
  (from efont-unicode) as fallback fonts.
* Fri Apr  2 2004 tiwai@suse.de
- return the exit code of the child process.
* Thu Apr  1 2004 tiwai@suse.de
- enhancement to fbiterm: allow direct invokation of commands,
  default font lists, -s option to accept font size via cmdline.
- fixed handling of fonts in fbiterm.  now GNU unifont works fine.
* Tue Mar  9 2004 mfabian@suse.de
- Bugzilla #34267: enable fribidi on x86_64 again, the problem
  was fixed by compiling fribidy with "-fno-strict-aliasing".
* Fri Mar  5 2004 mfabian@suse.de
- disable fribidi for the moment on x86_64, because xiterm and
  fbiterm crash immediately on this platform when fribidi is
  enabled.
- add intptr.patch to remove some compile warnings.
* Thu Mar  4 2004 mfabian@suse.de
- update to 0.5.20040304.
- remove first-column-missing.patch, xiterm.patch
  (included upstream).
* Wed Nov  5 2003 ro@suse.de
- fix build
* Sat Sep 20 2003 mfabian@suse.de
- Bugzilla #31448: the first character of each line/row
  was always missing in fbiterm.
* Mon Aug 25 2003 mfabian@suse.de
- update to 0.5.20030825.
- remove fbiterm-no-suid.patch, gtkiterm.patch (included upstream).
- fix typo in xiterm-fontset.patch
  (VT*fontSet1 had a trailing ',').
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Fri Jun 13 2003 mfabian@suse.de
- fix "directory not owned by any package".
* Thu Jan 30 2003 mfabian@suse.de
- update to 0.5.20030129
- add fbiterm-no-suid.patch and remove suid root bit from
  /usr/bin/fbiterm (with help from Gerd Knorr <kraxel@suse.de>
- add gtkiterm
* Sun Dec 22 2002 mfabian@suse.de
- remove xiterm.patch, xiterm-screen_visual_row.c.patch
  (included upstream)
- add --with-utempter configure option and 'utempter' to
  '# neededforbuild'
* Wed Dec 11 2002 mfabian@suse.de
- update to 0.4.20021206
- merge libiterm.spec and libXiterm.spec into xiterm.spec
- add xiterm.patch (thanks Gerd Knorr <kraxel@suse.de>)
  and xiterm-screen_visual_row.c.patch to make it work on x86_64.
* Wed Oct 23 2002 mfabian@suse.de
- update to 0.3.20021023
* Tue Oct 22 2002 mfabian@suse.de
- update to 0.3.20021022
* Wed Oct  2 2002 mfabian@suse.de
- new packages: xiterm and fbiterm version 0.2.20021001
